import Quickshell
import Quickshell.Services.Notifications
import QtQuick
import QtQuick.Layouts
import QtQml
import "base"
import "widgets/mpris"
import "widgets/notifications"
import "provider"

PanelWindow {
    id: homeWindow

    required property var root
    property bool animRunning: false

    color: "transparent"
    visible: animRunning || homeWindow.root.enabled
    focusable: true

    anchors {
        top: true
        left: true
        bottom: true
        right: true
    }

    MouseArea {
        id: mouse

        anchors.fill: parent

        onClicked: homeWindow.root.enabled = false

        BRectangle {
            id: home

            property var maxSize: 0

            bottomRightRadius: 10
            topRightRadius: 10
            border.color: "transparent"
            height: parent.height
            width: homeWindow.root.enabled ? maxSize : 0
            clip: true
            MouseArea {
                anchors.fill: parent
            }

            Component.onCompleted: () => maxSize = homeWindow.screen.width * (2 / 7)

            Behavior on width {
                PropertyAnimation {
                    id: anim
                    duration: 200
                    Component.onCompleted: () => {
                        homeWindow.animRunning = Qt.binding(() => anim.running);
                    }
                }
            }

            RowLayout {
                anchors.fill: parent

                Item {
                    width: 30
                    Layout.fillHeight: true
                }

                ColumnLayout {
                    Layout.fillHeight: true
                    Layout.fillWidth: true
                    height: parent.height
                    Layout.margins: 15
                    Layout.alignment: Qt.AlignBottom

                    ListView {
                        id: popupcol
                        Layout.fillHeight: true
                        Layout.fillWidth: true
                        Layout.preferredHeight: 1000
                        spacing: 10
                        width: parent.width

                        model: ListModel {
                            id: list
                            Component.onCompleted: () => {
                                Notifications._.notification.connect(e => {
                                    list.append({
                                        notif: e
                                    });
                                });
                            }
                        }

                        delegate: NotificationToast {
                            id: toast

                            required property int index

                            width: ListView.view.width

                            Component.onCompleted: {
                                toast.notif.closed.connect(e => {
                                    if (!toast)
                                        return;

                                    list.remove(toast.index, 1);
                                });

                                toast.close.connect(() => {
                                    const notif = toast.notif;

                                    list.remove(toast.index, 1);
                                    notif.dismiss();
                                });
                            }
                        }
                    }

                    MprisSmall {}
                }
            }
        }
    }
}
